@@ -2,6 +2,7 @@
  * Copyright (C) 2005 Ray Strode <rstrode@redhat.com>,
  *                    Matthias Clasen <mclasen@redhat.com>,
  *                    Søren Sandmann <sandmann@redhat.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License as
@@ -74,49 +75,6 @@
 #define GAMMA 2.2
 #endif
 
-static gboolean should_show_paths = FALSE;
-static gboolean should_do_rotations = FALSE;
-static gboolean should_print_stats = FALSE;
-static gint max_floater_count = FLOATER_DEFAULT_COUNT;
-static gchar *geometry = NULL;
-static gchar **filenames = NULL;
-
-static GOptionEntry options[] =
-{
-	{
-		"show-paths", 'p', 0, G_OPTION_ARG_NONE, &should_show_paths,
-		N_("Show paths that images follow"), NULL
-	},
-
-	{
-		"do-rotations", 'r', 0, G_OPTION_ARG_NONE, &should_do_rotations,
-		N_("Occasionally rotate images as they move"), NULL
-	},
-
-	{
-		"print-stats", 's', 0, G_OPTION_ARG_NONE, &should_print_stats,
-		N_("Print out frame rate and other statistics"), NULL
-	},
-
-	{
-		"number-of-images", 'n', 0, G_OPTION_ARG_INT, &max_floater_count,
-		N_("The maximum number of images to keep on screen"), N_("MAX_IMAGES")
-	},
-
-	{
-		"geometry", 0, 0, G_OPTION_ARG_STRING, &geometry,
-		N_("The initial size and position of window"), N_("WIDTHxHEIGHT+X+Y")
-	},
-
-	{
-		G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames,
-		N_("The source image to use"), NULL
-	},
-
-	{NULL}
-};
-
-
 typedef struct _Point Point;
 typedef struct _Path Path;
 typedef struct _Rectangle Rectangle;
@@ -417,7 +375,7 @@ screen_saver_floater_should_come_on_screen (ScreenSaver        *screen_saver,
 	if (!screen_saver_floater_is_off_canvas (screen_saver, floater))
 		return FALSE;
 
-	if ((abs (performance_ratio - .5) >= G_MINDOUBLE) &&
+	if ((fabs (performance_ratio - .5) >= G_MINDOUBLE) &&
 	        (g_random_double () > .5))
 	{
 		if (duration)
@@ -582,7 +540,7 @@ screen_saver_floater_create_path (ScreenSaver        *screen_saver,
 	performance_ratio =
 	    screen_saver_get_frames_per_second (screen_saver) / OPTIMAL_FRAME_RATE;
 
-	if (abs (performance_ratio) <= G_MINDOUBLE)
+	if (fabs (performance_ratio) <= G_MINDOUBLE)
 		performance_ratio = 1.0;
 
 	if (screen_saver_floater_should_bubble_up (screen_saver, floater, performance_ratio, &duration))
@@ -732,7 +690,7 @@ screen_saver_floater_do_draw (ScreenSaver        *screen_saver,
 
 	cairo_save (context);
 
-	if (screen_saver->should_do_rotations && (abs (floater->angle) > G_MINDOUBLE))
+	if (screen_saver->should_do_rotations && (fabs (floater->angle) > G_MINDOUBLE))
 	{
 		floater->bounds.width = G_SQRT2 * source->width + 2;
 		floater->bounds.height = G_SQRT2 * source->height + 2;
@@ -1001,7 +959,7 @@ compare_floaters (ScreenSaverFloater *a,
 {
 	if (a->scale > b->scale)
 		return 1;
-	else if (abs (a->scale - b->scale) <= G_MINDOUBLE)
+	else if (fabs (a->scale - b->scale) <= G_MINDOUBLE)
 		return 0;
 	else
 		return -1;
@@ -1133,7 +1091,7 @@ screen_saver_do_update_stats (ScreenSaver *screen_saver)
 	    screen_saver_get_timestamp (screen_saver);
 	screen_saver->last_calculated_stats_time = last_calculated_stats_time;
 
-	if (abs (last_calculated_stats_time) <= G_MINDOUBLE)
+	if (fabs (last_calculated_stats_time) <= G_MINDOUBLE)
 		return TRUE;
 
 	seconds_since_last_stats_update =
@@ -1170,9 +1128,29 @@ main (int   argc,
 	ScreenSaver     *screen_saver;
 	GtkWidget       *window;
 	GtkWidget       *drawing_area;
-	GError *error;
+	gboolean         should_show_paths = FALSE;
+	gboolean         should_do_rotations = FALSE;
+	gboolean         should_print_stats = FALSE;
+	gint             max_floater_count = FLOATER_DEFAULT_COUNT;
+	gchar           *geometry = NULL;
+	gchar          **filenames = NULL;
+	GError          *error = NULL;
 
-	error = NULL;
+	GOptionEntry options[] = {
+	        { "show-paths", 'p', 0, G_OPTION_ARG_NONE, &should_show_paths,
+		  N_("Show paths that images follow"), NULL },
+		{ "do-rotations", 'r', 0, G_OPTION_ARG_NONE, &should_do_rotations,
+		  N_("Occasionally rotate images as they move"), NULL },
+		{ "print-stats", 's', 0, G_OPTION_ARG_NONE, &should_print_stats,
+		  N_("Print out frame rate and other statistics"), NULL },
+		{ "number-of-images", 'n', 0, G_OPTION_ARG_INT, &max_floater_count,
+		  N_("The maximum number of images to keep on screen"), N_("MAX_IMAGES") },
+		{ "geometry", 0, 0, G_OPTION_ARG_STRING, &geometry,
+		  N_("The initial size and position of window"), N_("WIDTHxHEIGHT+X+Y") },
+		{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames,
+		  N_("The source image to use"), NULL },
+		{NULL}
+	};
 
 	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
