@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2004-2006 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,6 +59,10 @@
 
 #define KEY_LOCK_DIALOG_THEME "lock-dialog-theme"
 
+#define KEY_LOCK_DIALOG_T_FMT "lock-dialog-time-format"
+#define KEY_LOCK_DIALOG_D_FMT "lock-dialog-date-format"
+
+
 #define MDM_FLEXISERVER_COMMAND "mdmflexiserver"
 #define MDM_FLEXISERVER_ARGS    "--startnew Standard"
 
@@ -293,12 +298,42 @@ date_time_update (GSLockPlug *plug)
 	GDateTime *datetime;
 	gchar *time;
 	gchar *date;
+	gchar *tfmt;
+	gchar *dfmt;
+
 	gchar *str;
 
+	GSettings *settings;
+
+	settings = g_settings_new (GSETTINGS_SCHEMA);
+	tfmt = g_settings_get_string (settings, KEY_LOCK_DIALOG_T_FMT);
+	dfmt = g_settings_get_string (settings, KEY_LOCK_DIALOG_D_FMT);
+	g_object_unref (settings);
+
+	/* Time/Date formating https://developer.gnome.org/glib/stable/glib-GDateTime.html#g-date-time-format */
+
 	datetime = g_date_time_new_now_local ();
-	time = g_date_time_format (datetime, "%X");
-	/* Translators: Date format, see https://developer.gnome.org/glib/stable/glib-GDateTime.html#g-date-time-format */
-	date = g_date_time_format (datetime, _("%A, %B %e"));
+	if (g_strcmp0(tfmt, "locale") == 0)
+	{
+		// Use locale default format
+		time = g_date_time_format (datetime, "%X");
+	}
+	else
+	{
+		// Apply user defined format
+		time = g_date_time_format (datetime, tfmt);
+	}
+
+	if (g_strcmp0(dfmt, "locale") == 0)
+	{
+		// Use locale default format
+		date = g_date_time_format (datetime, _("%A, %B %e"));
+	}
+	else
+	{
+		// Apply user defined format
+		date = g_date_time_format (datetime, dfmt);
+	}
 
 	str = g_strdup_printf ("<span size=\"xx-large\" weight=\"ultrabold\">%s</span>", time);
 	gtk_label_set_text (GTK_LABEL (plug->priv->auth_time_label), str);
@@ -312,6 +347,8 @@ date_time_update (GSLockPlug *plug)
 
 	g_free (time);
 	g_free (date);
+	g_free (tfmt);
+	g_free (dfmt);
 	g_date_time_unref (datetime);
 }
 
@@ -387,8 +424,10 @@ gs_lock_plug_response (GSLockPlug *plug,
 }
 
 static gboolean
-response_cancel_idle_cb (GSLockPlug *plug)
+response_cancel_idle_cb (gpointer user_data)
 {
+	GSLockPlug *plug = user_data;
+
 	plug->priv->response_idle_id = 0;
 
 	gs_lock_plug_response (plug, GS_LOCK_PLUG_RESPONSE_CANCEL);
@@ -397,8 +436,10 @@ response_cancel_idle_cb (GSLockPlug *plug)
 }
 
 static gboolean
-dialog_timed_out (GSLockPlug *plug)
+dialog_timed_out (gpointer user_data)
 {
+	GSLockPlug *plug = user_data;
+
 	gs_lock_plug_set_sensitive (plug, FALSE);
 	set_status_text (plug, _("Time has expired."));
 
@@ -410,8 +451,8 @@ dialog_timed_out (GSLockPlug *plug)
 	remove_response_idle (plug);
 
 	plug->priv->response_idle_id = g_timeout_add (2000,
-	                               (GSourceFunc)response_cancel_idle_cb,
-	                               plug);
+	                                              response_cancel_idle_cb,
+	                                              plug);
 	return FALSE;
 }
 
@@ -462,8 +503,8 @@ restart_cancel_timeout (GSLockPlug *plug)
 	remove_cancel_timeout (plug);
 
 	plug->priv->cancel_timeout_id = g_timeout_add (plug->priv->timeout,
-	                                (GSourceFunc)dialog_timed_out,
-	                                plug);
+	                                               dialog_timed_out,
+	                                               plug);
 }
 
 void
@@ -1950,8 +1991,8 @@ switch_user_button_clicked (GtkButton  *button,
 	gs_lock_plug_set_sensitive (plug, FALSE);
 
 	plug->priv->response_idle_id = g_timeout_add (2000,
-	        (GSourceFunc)response_cancel_idle_cb,
-	        plug);
+	                                              response_cancel_idle_cb,
+	                                              plug);
 
 	gs_lock_plug_set_busy (plug);
 	do_user_switch (plug);
@@ -2099,6 +2140,30 @@ on_note_text_buffer_changed (GtkTextBuffer *buffer,
 	gtk_widget_set_sensitive (plug->priv->note_ok_button, len <= NOTE_BUFFER_MAX_CHARS);
 }
 
+static void
+entry_icon_clicked (GtkEntry       *entry,
+                    gint            position,
+                    GdkEventButton *event,
+                    gpointer        data)
+{
+	(void)data;
+
+	if ((position == GTK_ENTRY_ICON_SECONDARY) && (event->type == GDK_DOUBLE_BUTTON_PRESS))
+	{
+		if (g_strcmp0 (gtk_entry_get_icon_name (entry, position), "emblem-readonly"))
+		{
+			gtk_entry_set_icon_from_icon_name (entry, position, "emblem-readonly");
+			gtk_entry_set_icon_tooltip_text (entry, position, _("Show password"));
+			gtk_entry_set_visibility (entry, FALSE);
+		}
+		else
+		{
+			gtk_entry_set_icon_from_icon_name (entry, position, "emblem-unreadable");
+			gtk_entry_set_icon_tooltip_text (entry, position, _("Hide password"));
+			gtk_entry_set_visibility (entry, TRUE);
+		}
+	}
+}
 static void
 gs_lock_plug_init (GSLockPlug *plug)
 {
@@ -2141,7 +2206,7 @@ gs_lock_plug_init (GSLockPlug *plug)
 		date_time_update (plug);
 		gtk_widget_show_all (plug->priv->vbox);
 	}
-	plug->priv->datetime_timeout_id = g_timeout_add_seconds (1, (GSourceFunc) date_time_update, plug);
+	plug->priv->datetime_timeout_id = g_timeout_add_seconds (1, G_SOURCE_FUNC (date_time_update), plug);
 
 	if (plug->priv->note_text_view != NULL)
 	{
@@ -2235,6 +2300,10 @@ gs_lock_plug_init (GSLockPlug *plug)
 	gtk_entry_set_activates_default (GTK_ENTRY (plug->priv->auth_prompt_entry), TRUE);
 	gtk_entry_set_visibility (GTK_ENTRY (plug->priv->auth_prompt_entry), FALSE);
 
+	/* show/hide password */
+	g_signal_connect (plug->priv->auth_prompt_entry, "icon-press",
+	                  G_CALLBACK (entry_icon_clicked), NULL);
+
 	g_signal_connect (plug->priv->auth_unlock_button, "clicked",
 	                  G_CALLBACK (unlock_button_clicked), plug);
 
