@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2004-2006 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -329,8 +330,9 @@ oom:
 }
 
 static gboolean
-do_command (DBusConnection *connection)
+do_command (gpointer data)
 {
+	DBusConnection *connection = data;
 	DBusMessage *reply;
 
 	if (do_quit)
@@ -545,7 +547,7 @@ main (int    argc,
 		exit (1);
 	}
 
-	g_idle_add ((GSourceFunc)do_command, connection);
+	g_idle_add (do_command, connection);
 
 	loop = g_main_loop_new (NULL, FALSE);
 	g_main_loop_run (loop);
